# hibp-py

hibp-py is a Python library that facilitates the analysis and tracking of breaches posted to haveibeenpwned.

## Installation

1. Install from pip: `pip install hibp-py`

## Contributing

If you'd like to contribute to the project, please follow these steps:

1. Fork the repository.
2. Create a new branch for your changes: `git checkout -b my-new-feature`.
3. Make your changes and commit them: `git commit -am 'Add some feature'`.
4. Push to the branch: `git push origin my-new-feature`.
5. Submit a pull request.

## License

hibp-py is licensed under the [MIT License](https://opensource.org/licenses/MIT). Feel free to use it for personal or commercial use.
